AdecorrelateSettings class final

Configuration for the adecorrelate audio effect.

Apply decorrelation to input audio stream.

The filter accepts the following options:

Parameters:

  • seed: Set random seed used for setting delay in samples across channels. (range -1..4294967295, default -1)
  • stages: Set decorrelation stages of filtering. Allowed range is from 1 to 16. Default value is 6. (range 1..16, default 6)

Constructors

AdecorrelateSettings({bool enabled = false, int seed = -1, int stages = 6})
Creates an AdecorrelateSettings with the given parameter values.
const

Properties

enabled bool
Whether this effect is inserted into the audio chain.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int
set random seed
final
stages int
set filtering stages
final

Methods

copyWith({bool? enabled, int? seed, int? stages}) AdecorrelateSettings
Returns a copy of this AdecorrelateSettings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

seedDefault → const int
Default value for seed.
seedMax → const int
Maximum value for seed.
seedMin → const int
Minimum value for seed.
stagesDefault → const int
Default value for stages.
stagesMax → const int
Maximum value for stages.
stagesMin → const int
Minimum value for stages.