AdynamicequalizerAuto enum

Values for the auto option of the adynamicequalizer audio filter.

Inheritance
Available extensions

Values

disabled → const AdynamicequalizerAuto

The disabled option value.

off → const AdynamicequalizerAuto

The off option value.

on_ → const AdynamicequalizerAuto

The on option value.

adaptive → const AdynamicequalizerAuto

The adaptive option value.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
mpvValue String
Wire-side string consumed by mpv.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMpv(String? raw) AdynamicequalizerAuto
Parses a mpv wire string back into a AdynamicequalizerAuto. Unknown / empty input falls back to the first member.

Constants

values → const List<AdynamicequalizerAuto>
A constant List of the values in this enum, in order of their declaration.