AechoSettings class final

Configuration for the aecho audio effect.

Apply echoing to the input audio.

Echoes are reflected sound and can occur naturally amongst mountains (and sometimes large buildings) when talking or shouting; digital echo effects emulate this behaviour and are often used to help fill out the sound of a single instrument or vocal. The time difference between the original signal and the reflection is the delay, and the loudness of the reflected signal is the decay. Multiple echoes can have different delays and decays.

A description of the accepted parameters follows.

Parameters:

  • decays: Set list of loudness of reflected signals separated by '|'. Allowed range for each decay is (0 - 1.0]. Default is 0.5. (range 0..0, default "0.5")
  • delays: Set list of time intervals in milliseconds between original signal and reflections separated by '|'. Allowed range for each delay is (0 - 90000.0]. Default is 1000. (range 0..0, default "1000")
  • in_gain: Set input gain of reflected signal. Default is 0.6. (range 0..1, default 0.6)
  • out_gain: Set output gain of reflected signal. Default is 0.3. (range 0..1, default 0.3)
Available extensions

Constructors

AechoSettings({bool enabled = false, String decays = '0.5', String delays = '1000', double in_gain = 0.6, double out_gain = 0.3})
Creates an AechoSettings with the given parameter values.
const

Properties

decays String
set list of signal decays
final
delays String
set list of signal delays
final
enabled bool
Whether this effect is inserted into the audio chain.
final
hashCode int
The hash code for this object.
no setteroverride
in_gain double
set signal input gain
final
out_gain double
set signal output gain
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taps List<AechoTap>

Available on AechoSettings, provided by the AechoTapsX extension

Decoded list of taps in declaration order.
no setter

Methods

copyWith({bool? enabled, String? decays, String? delays, double? in_gain, double? out_gain}) AechoSettings
Returns a copy of this AechoSettings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override
withTaps(List<AechoTap> taps) AechoSettings

Available on AechoSettings, provided by the AechoTapsX extension

Returns a copy whose delays / decays reflect taps.

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

in_gainDefault → const double
Default value for in_gain.
in_gainMax → const double
Maximum value for in_gain.
in_gainMin → const double
Minimum value for in_gain.
out_gainDefault → const double
Default value for out_gain.
out_gainMax → const double
Maximum value for out_gain.
out_gainMin → const double
Minimum value for out_gain.