AfadeCurve enum

Values for the c option of the afade audio filter.

Inheritance
Available extensions

Values

nofade → const AfadeCurve

no fade; keep audio as-is

tri → const AfadeCurve

linear slope

qsin → const AfadeCurve

quarter of sine wave

esin → const AfadeCurve

exponential sine wave

hsin → const AfadeCurve

half of sine wave

log → const AfadeCurve

logarithmic

ipar → const AfadeCurve

inverted parabola

qua → const AfadeCurve

quadratic

cub → const AfadeCurve

cubic

squ → const AfadeCurve

square root

cbr → const AfadeCurve

cubic root

par → const AfadeCurve

parabola

exp → const AfadeCurve

exponential

iqsin → const AfadeCurve

inverted quarter of sine wave

ihsin → const AfadeCurve

inverted half of sine wave

dese → const AfadeCurve

double-exponential seat

desi → const AfadeCurve

double-exponential sigmoid

losi → const AfadeCurve

logistic sigmoid

sinc → const AfadeCurve

sine cardinal function

isinc → const AfadeCurve

inverted sine cardinal function

quat → const AfadeCurve

quartic

quatr → const AfadeCurve

quartic root

qsin2 → const AfadeCurve

squared quarter of sine wave

hsin2 → const AfadeCurve

squared half of sine wave

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
mpvValue String
Wire-side string consumed by mpv.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMpv(String? raw) AfadeCurve
Parses a mpv wire string back into a AfadeCurve. Unknown / empty input falls back to the first member.

Constants

values → const List<AfadeCurve>
A constant List of the values in this enum, in order of their declaration.