AiirPrecision enum

Values for the e option of the aiir audio filter.

Inheritance
Available extensions

Values

dbl → const AiirPrecision

double-precision floating-point

flt → const AiirPrecision

single-precision floating-point

i32 → const AiirPrecision

32-bit integers

i16 → const AiirPrecision

16-bit integers

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
mpvValue → String
Wire-side string consumed by mpv.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMpv(String? raw) → AiirPrecision
Parses a mpv wire string back into a AiirPrecision. Unknown / empty input falls back to the first member.

Constants

values → const List<AiirPrecision>
A constant List of the values in this enum, in order of their declaration.