AphaserSettings class final

Configuration for the aphaser audio effect.

Add a phasing effect to the input audio.

A phaser filter creates series of peaks and troughs in the frequency spectrum. The position of the peaks and troughs are modulated so that they vary over time, creating a sweeping effect.

A description of the accepted parameters follows.

Parameters:

  • decay: Set decay. Default is 0.4. (range 0...99, default .4)
  • delay: Set delay in milliseconds. Default is 3.0. (range 0..5, default 3.)
  • in_gain: Set input gain. Default is 0.4. (range 0..1, default .4)
  • out_gain: Set output gain. Default is 0.74 (range 0..1e9, default .74)
  • speed: Set modulation speed in Hz. Default is 0.5. (range .1..2, default .5)
  • type: Set modulation type. Default is triangular. It accepts the following values: (default WAVE_TRI)

Constructors

AphaserSettings({bool enabled = false, double decay = .4, double delay = 3.0, double in_gain = .4, double out_gain = .74, double speed = .5, AphaserType type = AphaserType.triangular})
Creates an AphaserSettings with the given parameter values.
const

Properties

decay → double
set decay
final
delay → double
set delay in milliseconds
final
enabled → bool
Whether this effect is inserted into the audio chain.
final
hashCode → int
The hash code for this object.
no setteroverride
in_gain → double
set input gain
final
out_gain → double
set output gain
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double
set modulation speed
final
type → AphaserType
set modulation type
final

Methods

copyWith({bool? enabled, double? decay, double? delay, double? in_gain, double? out_gain, double? speed, AphaserType? type}) → AphaserSettings
Returns a copy of this AphaserSettings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() → String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

decayDefault → const double
Default value for decay.
decayMax → const double
Maximum value for decay.
decayMin → const double
Minimum value for decay.
delayDefault → const double
Default value for delay.
delayMax → const double
Maximum value for delay.
delayMin → const double
Minimum value for delay.
in_gainDefault → const double
Default value for in_gain.
in_gainMax → const double
Maximum value for in_gain.
in_gainMin → const double
Minimum value for in_gain.
out_gainDefault → const double
Default value for out_gain.
out_gainMax → const double
Maximum value for out_gain.
out_gainMin → const double
Minimum value for out_gain.
speedDefault → const double
Default value for speed.
speedMax → const double
Maximum value for speed.
speedMin → const double
Minimum value for speed.