ApulsatorSettings class final

Configuration for the apulsator audio effect.

Audio pulsator is something between an autopanner and a tremolo. But it can produce funny stereo effects as well. Pulsator changes the volume of the left and right channel based on a LFO (low frequency oscillator) with different waveforms and shifted phases. This filter have the ability to define an offset between left and right channel. An offset of 0 means that both LFO shapes match each other. The left and right channel are altered equally - a conventional tremolo. An offset of 50% means that the shape of the right channel is exactly shifted in phase (or moved backwards about half of the frequency) - pulsator acts as an autopanner. At 1 both curves match again. Every setting in between moves the phase shift gapless between all stages and produces some "bypassing" sounds with sine and triangle waveforms. The more you set the offset near 1 (starting from the 0.5) the faster the signal passes from the left to the right speaker.

The filter accepts the following options:

Parameters:

  • amount: Set modulation. Define how much of original signal is affected by the LFO. (range 0..1, default 1)
  • bpm: Set bpm. Default is 120. Allowed range is 30 - 300. Only used if timing is set to bpm. (range 30..300, default 120)
  • hz: Set frequency in Hz. Default is 2. Allowed range is 0.01 - 100. Only used if timing is set to hz. (range 0.01..100, default 2)
  • level_in: Set input gain. By default it is 1. Range is 0.015625 - 64. (range 0.015625..64, default 1)
  • level_out: Set output gain. By default it is 1. Range is 0.015625 - 64. (range 0.015625..64, default 1)
  • mode: Set waveform shape the LFO will use. Can be one of: sine, triangle, square, sawup or sawdown. Default is sine. (range 0..4, default SINE)
  • ms: Set ms. Default is 500. Allowed range is 10 - 2000. Only used if timing is set to ms. (range 10..2000, default 500)
  • offset_l: Set left channel offset. Default is 0. Allowed range is 0 - 1. (range 0..1, default 0)
  • offset_r: Set right channel offset. Default is 0.5. Allowed range is 0 - 1. (range 0..1, default .5)
  • timing: Set possible timing mode. Can be one of: bpm, ms or hz. Default is hz. (range 0..2, default 2)
  • width: Set pulse width. Default is 1. Allowed range is 0 - 2. (range 0..2, default 1)

Constructors

ApulsatorSettings({bool enabled = false, double amount = 1.0, double bpm = 120.0, double hz = 2.0, double level_in = 1.0, double level_out = 1.0, ApulsatorMode mode = ApulsatorMode.sine, int ms = 500, double offset_l = 0.0, double offset_r = .5, ApulsatorTiming timing = ApulsatorTiming.hz, double width = 1.0})
Creates an ApulsatorSettings with the given parameter values.
const

Properties

amount double
set modulation
final
bpm double
set BPM
final
enabled bool
Whether this effect is inserted into the audio chain.
final
hashCode int
The hash code for this object.
no setteroverride
hz double
set frequency
final
level_in double
set input gain
final
level_out double
set output gain
final
mode ApulsatorMode
set mode
final
ms int
set ms
final
offset_l double
set offset L
final
offset_r double
set offset R
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timing ApulsatorTiming
set timing
final
width double
set pulse width
final

Methods

copyWith({bool? enabled, double? amount, double? bpm, double? hz, double? level_in, double? level_out, ApulsatorMode? mode, int? ms, double? offset_l, double? offset_r, ApulsatorTiming? timing, double? width}) ApulsatorSettings
Returns a copy of this ApulsatorSettings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

amountDefault → const double
Default value for amount.
amountMax → const double
Maximum value for amount.
amountMin → const double
Minimum value for amount.
bpmDefault → const double
Default value for bpm.
bpmMax → const double
Maximum value for bpm.
bpmMin → const double
Minimum value for bpm.
hzDefault → const double
Default value for hz.
hzMax → const double
Maximum value for hz.
hzMin → const double
Minimum value for hz.
level_inDefault → const double
Default value for level_in.
level_inMax → const double
Maximum value for level_in.
level_inMin → const double
Minimum value for level_in.
level_outDefault → const double
Default value for level_out.
level_outMax → const double
Maximum value for level_out.
level_outMin → const double
Minimum value for level_out.
msDefault → const int
Default value for ms.
msMax → const int
Maximum value for ms.
msMin → const int
Minimum value for ms.
offset_lDefault → const double
Default value for offset_l.
offset_lMax → const double
Maximum value for offset_l.
offset_lMin → const double
Minimum value for offset_l.
offset_rDefault → const double
Default value for offset_r.
offset_rMax → const double
Maximum value for offset_r.
offset_rMin → const double
Minimum value for offset_r.
widthDefault → const double
Default value for width.
widthMax → const double
Maximum value for width.
widthMin → const double
Minimum value for width.