AresampleSettings class final

Configuration for the aresample audio effect.

Resample the input audio to the specified parameters, using the libswresample library. If none are specified then the filter will automatically convert between its input and output.

This filter is also able to stretch/squeeze the audio data to make it match the timestamps or to inject silence / cut out audio to make it match the timestamps, do a combination of both or do neither.

The filter accepts the syntax `sample_rate`:resampler_options, where sample_rate expresses a sample rate and resampler_options is a list of key=value pairs, separated by ":". See the Resampler Options for the complete list of supported options.

Resample the input audio to 44100Hz:

  • Stretch/squeeze samples to the given timestamps, with a maximum of 1000 samples per second compensation:

Parameters:

Constructors

AresampleSettings({bool enabled = false, int sample_rate = 0})
Creates an AresampleSettings with the given parameter values.
const

Properties

enabled bool
Whether this effect is inserted into the audio chain.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample_rate int
The sample_rate parameter.
final

Methods

copyWith({bool? enabled, int? sample_rate}) AresampleSettings
Returns a copy of this AresampleSettings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

sample_rateDefault → const int
Default value for sample_rate.
sample_rateMax → const int
Maximum value for sample_rate.
sample_rateMin → const int
Minimum value for sample_rate.