AtempoSettings class final

Configuration for the atempo audio effect.

Adjust audio tempo.

The filter accepts exactly one parameter, the audio tempo. If not specified then the filter will assume nominal 1.0 tempo. Tempo must be in the 0.5, 100.0 range.

Note that tempo greater than 2 will skip some samples rather than blend them in. If for any reason this is a concern it is always possible to daisy-chain several instances of atempo to achieve the desired product tempo.

Slow down audio to 80% tempo:

  • To speed up audio to 300% tempo:

  • To speed up audio to 300% tempo by daisy-chaining two atempo instances:

This filter supports the following commands:

Parameters:

  • tempo: Change filter tempo scale factor. Syntax for the command is : "tempo" (range 0.5..100.0, default 1.0, runtime-tunable)

Constructors

AtempoSettings({bool enabled = false, double tempo = 1.0})
Creates an AtempoSettings with the given parameter values.
const

Properties

enabled bool
Whether this effect is inserted into the audio chain.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tempo double
set tempo scale factor
final

Methods

copyWith({bool? enabled, double? tempo}) AtempoSettings
Returns a copy of this AtempoSettings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

tempoDefault → const double
Default value for tempo.
tempoMax → const double
Maximum value for tempo.
tempoMin → const double
Minimum value for tempo.