CompensationdelaySettings class final
Configuration for the compensationdelay audio effect.
Compensation Delay Line is a metric based delay to compensate differing positions of microphones or speakers.
For example, you have recorded guitar with two microphones placed in different locations. Because the front of sound wave has fixed speed in normal conditions, the phasing of microphones can vary and depends on their location and interposition. The best sound mix can be achieved when these microphones are in phase (synchronized). Note that a distance of ~30 cm between microphones makes one microphone capture the signal in antiphase to the other microphone. That makes the final mix sound moody. This filter helps to solve phasing problems by adding different delays to each microphone track and make them synchronized.
The best result can be reached when you take one track as base and synchronize other tracks one by one with it. Remember that synchronization/delay tolerance depends on sample rate, too. Higher sample rates will give more tolerance.
The filter accepts the following parameters:
Parameters:
- cm: Set cm distance. This is compensation distance for tightening distance setup. Default is 0. (range 0..100, default 0)
- dry: Set dry amount. Amount of unprocessed (dry) signal. Default is 0. (range 0..1, default 0)
- m: Set meters distance. This is compensation distance for hard distance setup. Default is 0. (range 0..100, default 0)
- mm: Set millimeters distance. This is compensation distance for fine tuning. Default is 0. (range 0..10, default 0)
- temp: Set temperature in degrees Celsius. This is the temperature of the environment. Default is 20. (range -50..50, default 20)
- wet: Set wet amount. Amount of processed (wet) signal. Default is 1. (range 0..1, default 1)
Constructors
- CompensationdelaySettings({bool enabled = false, int cm = 0, double dry = 0.0, int m = 0, int mm = 0, int temp = 20, double wet = 1.0})
-
Creates an CompensationdelaySettings with the given parameter values.
const
Properties
- cm → int
-
set cm distance
final
- dry → double
-
set dry amount
final
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- m → int
-
set meter distance
final
- mm → int
-
set mm distance
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temp → int
-
set temperature °C
final
- wet → double
-
set wet amount
final
Methods
-
copyWith(
{bool? enabled, int? cm, double? dry, int? m, int? mm, int? temp, double? wet}) → CompensationdelaySettings - Returns a copy of this CompensationdelaySettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- cmDefault → const int
- Default value for cm.
- cmMax → const int
- Maximum value for cm.
- cmMin → const int
- Minimum value for cm.
- dryDefault → const double
- Default value for dry.
- dryMax → const double
- Maximum value for dry.
- dryMin → const double
- Minimum value for dry.
- mDefault → const int
- Default value for m.
- mMax → const int
- Maximum value for m.
- mmDefault → const int
- Default value for mm.
- mMin → const int
- Minimum value for m.
- mmMax → const int
- Maximum value for mm.
- mmMin → const int
- Minimum value for mm.
- tempDefault → const int
- Default value for temp.
- tempMax → const int
- Maximum value for temp.
- tempMin → const int
- Minimum value for temp.
- wetDefault → const double
- Default value for wet.
- wetMax → const double
- Maximum value for wet.
- wetMin → const double
- Minimum value for wet.