Ebur128Mode enum

Values for the peak option of the ebur128 audio filter.

Inheritance
Available extensions

Values

none → const Ebur128Mode

disable any peak mode

sample → const Ebur128Mode

enable peak-sample mode

true_ → const Ebur128Mode

enable true-peak mode

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
mpvValue → String
Wire-side string consumed by mpv.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMpv(String? raw) → Ebur128Mode
Parses a mpv wire string back into a Ebur128Mode. Unknown / empty input falls back to the first member.

Constants

values → const List<Ebur128Mode>
A constant List of the values in this enum, in order of their declaration.