RubberbandPitch enum

Values for the pitchq option of the rubberband audio filter.

Inheritance
Available extensions

Values

quality → const RubberbandPitch

The quality option value.

speed → const RubberbandPitch

The speed option value.

consistency → const RubberbandPitch

The consistency option value.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
mpvValue String
Wire-side string consumed by mpv.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMpv(String? raw) RubberbandPitch
Parses a mpv wire string back into a RubberbandPitch. Unknown / empty input falls back to the first member.

Constants

values → const List<RubberbandPitch>
A constant List of the values in this enum, in order of their declaration.