VibratoSettings class final
Configuration for the vibrato audio effect.
Sinusoidal phase modulation.
The filter accepts the following options:
Parameters:
Constructors
- VibratoSettings({bool enabled = false, double d = 0.5, double f = 5.0})
-
Creates an VibratoSettings with the given parameter values.
const
Properties
- d → double
-
set depth as percentage
final
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- f → double
-
set frequency in hertz
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? enabled, double? d, double? f}) → VibratoSettings - Returns a copy of this VibratoSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override