AdeclipSettings class final
Configuration for the adeclip audio effect.
Remove clipped samples from input audio.
Samples detected as clipped are replaced by interpolated samples using autoregressive modelling.
Parameters:
- a: Set autoregression order, in percentage of window size. Allowed range is from
0to25. Default value is8percent. This option also controls quality of interpolated samples using neighbour good samples. (range 0..25, default 8) - arorder: Set autoregression order, in percentage of window size. Allowed range is from
0to25. Default value is8percent. This option also controls quality of interpolated samples using neighbour good samples. (range 0..25, default 8) - hsize: Set size of histogram used to detect clips. Allowed range is from
100to9999. Default value is1000. Higher values make clip detection less aggressive. (range 100..9999, default 1000) - m: Set overlap method. It accepts the following values: (range 0..1, default 0)
- method: Set overlap method. It accepts the following values: (range 0..1, default 0)
- n: Set size of histogram used to detect clips. Allowed range is from
100to9999. Default value is1000. Higher values make clip detection less aggressive. (range 100..9999, default 1000) - o: Set window overlap, in percentage of window size. Allowed range is from
50to95. Default value is75percent. (range 50..95, default 75) - overlap: Set window overlap, in percentage of window size. Allowed range is from
50to95. Default value is75percent. (range 50..95, default 75) - t: Set threshold value. Allowed range is from
1to100. Default value is10. Higher values make clip detection less aggressive. (range 1..100, default 10) - threshold: Set threshold value. Allowed range is from
1to100. Default value is10. Higher values make clip detection less aggressive. (range 1..100, default 10) - w: Set window size, in milliseconds. Allowed range is from
10to100. Default value is55milliseconds. This sets size of window which will be processed at once. (range 10..100, default 55) - window: Set window size, in milliseconds. Allowed range is from
10to100. Default value is55milliseconds. This sets size of window which will be processed at once. (range 10..100, default 55)
Constructors
- AdeclipSettings({bool enabled = false, double a = 8.0, double arorder = 8.0, int hsize = 1000, AdeclipM m = AdeclipM.add, AdeclipM method = AdeclipM.add, int n = 1000, double o = 75.0, double overlap = 75.0, double t = 10.0, double threshold = 10.0, double w = 55.0, double window = 55.0})
-
Creates an AdeclipSettings with the given parameter values.
const
Properties
- a → double
-
set autoregression order
final
- arorder → double
-
set autoregression order
final
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hsize → int
-
set histogram size
final
- m → AdeclipM
-
set overlap method
final
- method → AdeclipM
-
set overlap method
final
- n → int
-
set histogram size
final
- o → double
-
set window overlap
final
- overlap → double
-
set window overlap
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- t → double
-
set threshold
final
- threshold → double
-
set threshold
final
- w → double
-
set window size
final
- window → double
-
set window size
final
Methods
-
copyWith(
{bool? enabled, double? a, double? arorder, int? hsize, AdeclipM? m, AdeclipM? method, int? n, double? o, double? overlap, double? t, double? threshold, double? w, double? window}) → AdeclipSettings - Returns a copy of this AdeclipSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- aDefault → const double
- Default value for a.
- aMax → const double
- Maximum value for a.
- aMin → const double
- Minimum value for a.
- arorderDefault → const double
- Default value for arorder.
- arorderMax → const double
- Maximum value for arorder.
- arorderMin → const double
- Minimum value for arorder.
- hsizeDefault → const int
- Default value for hsize.
- hsizeMax → const int
- Maximum value for hsize.
- hsizeMin → const int
- Minimum value for hsize.
- nDefault → const int
- Default value for n.
- nMax → const int
- Maximum value for n.
- nMin → const int
- Minimum value for n.
- oDefault → const double
- Default value for o.
- oMax → const double
- Maximum value for o.
- oMin → const double
- Minimum value for o.
- overlapDefault → const double
- Default value for overlap.
- overlapMax → const double
- Maximum value for overlap.
- overlapMin → const double
- Minimum value for overlap.
- tDefault → const double
- Default value for t.
- thresholdDefault → const double
- Default value for threshold.
- thresholdMax → const double
- Maximum value for threshold.
- thresholdMin → const double
- Minimum value for threshold.
- tMax → const double
- Maximum value for t.
- tMin → const double
- Minimum value for t.
- wDefault → const double
- Default value for w.
- windowDefault → const double
- Default value for window.
- windowMax → const double
- Maximum value for window.
- windowMin → const double
- Minimum value for window.
- wMax → const double
- Maximum value for w.
- wMin → const double
- Minimum value for w.