AdecorrelateSettings class final

Configuration for the adecorrelate audio effect.

Apply decorrelation to input audio stream.

The filter accepts the following options:

Parameters:

  • stages: Set decorrelation stages of filtering. Allowed range is from 1 to 16. Default value is 6. (default 6)

Constructors

AdecorrelateSettings({bool enabled = false, int stages = 6})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stages int
final

Methods

copyWith({bool? enabled, int? stages}) AdecorrelateSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override