AderivativeSettings class final

Configuration for the aderivative audio effect.

Compute derivative/integral of audio stream.

Applying both filters one after another produces original audio.

Constructors

AderivativeSettings({bool enabled = false})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? enabled}) AderivativeSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override