AdynamicequalizerSettings class final
Configuration for the adynamicequalizer audio effect.
Apply dynamic equalization to input audio stream.
A description of the accepted options follows.
Parameters:
- attack: Set the amount of milliseconds the signal from detection has to rise above the detection threshold before equalization starts. Default is 20. Allowed range is between 1 and 2000. (range 0.01..2000, default 20, runtime-tunable)
- auto: set auto threshold (range 1..4, default DET_OFF, runtime-tunable)
- dfrequency: Set the detection frequency in Hz used for detection filter used to trigger equalization. Default value is 1000 Hz. Allowed range is between 2 and 1000000 Hz. (range 2..1000000, default 1000, runtime-tunable)
- dftype: set detection filter type (range 0..3, default 0, runtime-tunable)
- dqfactor: Set the detection resonance factor for detection filter used to trigger equalization. Default value is 1. Allowed range is from 0.001 to 1000. (range 0.001..1000, default 1, runtime-tunable)
- makeup: Set the makeup offset by which the equalization gain is raised. Default is 0. Allowed range is between 0 and 100. (range 0..1000, default 0, runtime-tunable)
- mode: Set the mode of filter operation, can be one of the following: (range -1..3, default 0, runtime-tunable)
- precision: set processing precision (range 0..2, default 0)
- range: Set the max allowed cut/boost amount. Default is 50. Allowed range is from 1 to 200. (range 1..2000, default 50, runtime-tunable)
- ratio: Set the ratio by which the equalization gain is raised. Default is 1. Allowed range is between 0 and 30. (range 0..30, default 1, runtime-tunable)
- release: Set the amount of milliseconds the signal from detection has to fall below the detection threshold before equalization ends. Default is 200. Allowed range is between 1 and 2000. (range 0.01..2000, default 200, runtime-tunable)
- tfrequency: Set the target frequency of equalization filter. Default value is 1000 Hz. Allowed range is between 2 and 1000000 Hz. (range 2..1000000, default 1000, runtime-tunable)
- tftype: set target filter type (range 0..2, default 0, runtime-tunable)
- threshold: Set the detection threshold used to trigger equalization. Threshold detection is using detection filter. Default value is 0. Allowed range is from 0 to 100. (range 0..100, default 0, runtime-tunable)
- tqfactor: Set the target resonance factor for target equalization filter. Default value is 1. Allowed range is from 0.001 to 1000. (range 0.001..1000, default 1, runtime-tunable)
Constructors
- AdynamicequalizerSettings({bool enabled = false, double attack = 20.0, AdynamicequalizerAuto auto = AdynamicequalizerAuto.off, double dfrequency = 1000.0, AdynamicequalizerDftype dftype = AdynamicequalizerDftype.bandpass, double dqfactor = 1.0, double makeup = 0.0, AdynamicequalizerMode mode = AdynamicequalizerMode.listen, AdynamicequalizerPrecision precision = AdynamicequalizerPrecision.auto, double range = 50.0, double ratio = 1.0, double release = 200.0, double tfrequency = 1000.0, AdynamicequalizerTftype tftype = AdynamicequalizerTftype.bell, double threshold = 0.0, double tqfactor = 1.0})
-
Creates an AdynamicequalizerSettings with the given parameter values.
const
Properties
- attack → double
-
set detection attack duration
final
- auto → AdynamicequalizerAuto
-
set auto threshold
final
- dfrequency → double
-
set detection frequency
final
- dftype → AdynamicequalizerDftype
-
set detection filter type
final
- dqfactor → double
-
set detection Q factor
final
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- makeup → double
-
set makeup gain
final
- mode → AdynamicequalizerMode
-
set mode
final
- precision → AdynamicequalizerPrecision
-
set processing precision
final
- range → double
-
set max gain
final
- ratio → double
-
set ratio factor
final
- release → double
-
set detection release duration
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tfrequency → double
-
set target frequency
final
- tftype → AdynamicequalizerTftype
-
set target filter type
final
- threshold → double
-
set detection threshold
final
- tqfactor → double
-
set target Q factor
final
Methods
-
copyWith(
{bool? enabled, double? attack, AdynamicequalizerAuto? auto, double? dfrequency, AdynamicequalizerDftype? dftype, double? dqfactor, double? makeup, AdynamicequalizerMode? mode, AdynamicequalizerPrecision? precision, double? range, double? ratio, double? release, double? tfrequency, AdynamicequalizerTftype? tftype, double? threshold, double? tqfactor}) → AdynamicequalizerSettings - Returns a copy of this AdynamicequalizerSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- attackDefault → const double
- Default value for attack.
- attackMax → const double
- Maximum value for attack.
- attackMin → const double
- Minimum value for attack.
- dfrequencyDefault → const double
- Default value for dfrequency.
- dfrequencyMax → const double
- Maximum value for dfrequency.
- dfrequencyMin → const double
- Minimum value for dfrequency.
- dqfactorDefault → const double
- Default value for dqfactor.
- dqfactorMax → const double
- Maximum value for dqfactor.
- dqfactorMin → const double
- Minimum value for dqfactor.
- makeupDefault → const double
- Default value for makeup.
- makeupMax → const double
- Maximum value for makeup.
- makeupMin → const double
- Minimum value for makeup.
- rangeDefault → const double
- Default value for range.
- rangeMax → const double
- Maximum value for range.
- rangeMin → const double
- Minimum value for range.
- ratioDefault → const double
- Default value for ratio.
- ratioMax → const double
- Maximum value for ratio.
- ratioMin → const double
- Minimum value for ratio.
- releaseDefault → const double
- Default value for release.
- releaseMax → const double
- Maximum value for release.
- releaseMin → const double
- Minimum value for release.
- tfrequencyDefault → const double
- Default value for tfrequency.
- tfrequencyMax → const double
- Maximum value for tfrequency.
- tfrequencyMin → const double
- Minimum value for tfrequency.
- thresholdDefault → const double
- Default value for threshold.
- thresholdMax → const double
- Maximum value for threshold.
- thresholdMin → const double
- Minimum value for threshold.
- tqfactorDefault → const double
- Default value for tqfactor.
- tqfactorMax → const double
- Maximum value for tqfactor.
- tqfactorMin → const double
- Minimum value for tqfactor.