AemphasisSettings class final
Configuration for the aemphasis audio effect.
Audio emphasis filter creates or restores material directly taken from LPs or emphased CDs with different filter curves. E.g. to store music on vinyl the signal has to be altered by a filter first to even out the disadvantages of this recording medium. Once the material is played back the inverse filter has to be applied to restore the distortion of the frequency response.
The filter accepts the following options:
Parameters:
- level_in: Set input gain. (range 0..64, default 1, runtime-tunable)
- level_out: Set output gain. (range 0..64, default 1, runtime-tunable)
- mode: Set filter mode. For restoring material use
reproductionmode, otherwise useproductionmode. Default isreproductionmode. (range 0..1, default 0, runtime-tunable) - type: Set filter type. Selects medium. Can be one of the following: (range 0..8, default 4, runtime-tunable)
Constructors
- AemphasisSettings({bool enabled = false, double level_in = 1.0, double level_out = 1.0, AemphasisMode mode = AemphasisMode.reproduction, AemphasisType type = AemphasisType.cd})
-
Creates an AemphasisSettings with the given parameter values.
const
Properties
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- level_in → double
-
set input gain
final
- level_out → double
-
set output gain
final
- mode → AemphasisMode
-
set filter mode
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AemphasisType
-
set filter type
final
Methods
-
copyWith(
{bool? enabled, double? level_in, double? level_out, AemphasisMode? mode, AemphasisType? type}) → AemphasisSettings - Returns a copy of this AemphasisSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- level_inDefault → const double
- Default value for level_in.
- level_inMax → const double
- Maximum value for level_in.
- level_inMin → const double
- Minimum value for level_in.
- level_outDefault → const double
- Default value for level_out.
- level_outMax → const double
- Maximum value for level_out.
- level_outMin → const double
- Minimum value for level_out.