AgateSettings class final

Configuration for the agate audio effect.

A gate is mainly used to reduce lower parts of a signal. This kind of signal processing reduces disturbing noise between useful signals.

Gating is done by detecting the volume below a chosen level threshold and dividing it by the factor set with ratio. The bottom of the noise floor is set via range. Because an exact manipulation of the signal would cause distortion of the waveform the reduction can be levelled over time. This is done by setting attack and release.

attack determines how long the signal has to fall below the threshold before any reduction will occur and release sets the time the signal has to rise above the threshold to reduce the reduction again. Shorter signals than the chosen attack time will be left untouched.

Parameters:

  • attack: Amount of milliseconds the signal has to rise above the threshold before gain reduction stops. Default is 20 milliseconds. Allowed range is from 0.01 to 9000. (range 0.01..9000, default 20)
  • detection: Choose if exact signal should be taken for detection or an RMS like one. Default is rms. Can be peak or rms. (range 0..1, default 1)
  • knee: Curve the sharp knee around the threshold to enter gain reduction more softly. Default is 2.828427125. Allowed range is from 1 to 8. (range 1..8, default 2.828427125)
  • level_in: Set input level before filtering. Default is 1. Allowed range is from 0.015625 to 64. (range 0.015625..64, default 1)
  • level_sc: set sidechain gain (range 0.015625..64, default 1)
  • link: Choose if the average level between all channels or the louder channel affects the reduction. Default is average. Can be average or maximum. (range 0..1, default 0)
  • makeup: Set amount of amplification of signal after processing. Default is 1. Allowed range is from 1 to 64. (range 1..64, default 1)
  • mode: Set the mode of operation. Can be upward or downward. Default is downward. If set to upward mode, higher parts of signal will be amplified, expanding dynamic range in upward direction. Otherwise, in case of downward lower parts of signal will be reduced. (range 0..1, default 0)
  • range: Set the level of gain reduction when the signal is below the threshold. Default is 0.06125. Allowed range is from 0 to 1. Setting this to 0 disables reduction and then filter behaves like expander. (range 0..1, default 0.06125)
  • ratio: Set a ratio by which the signal is reduced. Default is 2. Allowed range is from 1 to 9000. (range 1..9000, default 2)
  • release: Amount of milliseconds the signal has to fall below the threshold before the reduction is increased again. Default is 250 milliseconds. Allowed range is from 0.01 to 9000. (range 0.01..9000, default 250)
  • threshold: If a signal rises above this level the gain reduction is released. Default is 0.125. Allowed range is from 0 to 1. (range 0..1, default 0.125)

Constructors

AgateSettings({bool enabled = false, double attack = 20.0, AgateDetection detection = AgateDetection.rms, double knee = 2.828427125, double level_in = 1.0, double level_sc = 1.0, AgateLink link = AgateLink.average, double makeup = 1.0, AgateMode mode = AgateMode.downward, double range = 0.06125, double ratio = 2.0, double release = 250.0, double threshold = 0.125})
const

Properties

attack double
final
detection AgateDetection
final
enabled bool
final
hashCode int
The hash code for this object.
no setteroverride
knee double
final
level_in double
final
level_sc double
final
final
makeup double
final
mode AgateMode
final
range double
final
ratio double
final
release double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold double
final

Methods

copyWith({bool? enabled, double? attack, AgateDetection? detection, double? knee, double? level_in, double? level_sc, AgateLink? link, double? makeup, AgateMode? mode, double? range, double? ratio, double? release, double? threshold}) AgateSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFilterString() String
Returns the audio chain entry for this effect. Only non-default parameters are emitted.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override