AlimiterSettings class final
Configuration for the alimiter audio effect.
The limiter prevents an input signal from rising over a desired threshold. This limiter uses lookahead technology to prevent your signal from distorting. It means that there is a small delay after the signal is processed. Keep in mind that the delay it produces is the attack time you set.
The filter accepts the following options:
Parameters:
- asc: When gain reduction is always needed ASC takes care of releasing to an average reduction level rather than reaching a reduction of 0 in the release time. (range 0..1, default 0, runtime-tunable)
- asc_level: Select how much the release time is affected by ASC, 0 means nearly no changes in release time while 1 produces higher release times. (range 0..1, default 0.5, runtime-tunable)
- attack: The limiter will reach its attenuation level in this amount of time in milliseconds. Default is 5 milliseconds. (range 0.1..80, default 5, runtime-tunable)
- latency: Compensate the delay introduced by using the lookahead buffer set with attack parameter. Also flush the valid audio data in the lookahead buffer when the stream hits EOF. (range 0..1, default 0, runtime-tunable)
- level: Auto level output signal. Default is enabled. This normalizes audio back to 0dB if enabled. (range 0..1, default 1, runtime-tunable)
- level_in: Set input gain. Default is 1. (range .015625..64, default 1, runtime-tunable)
- level_out: Set output gain. Default is 1. (range .015625..64, default 1, runtime-tunable)
- limit: Don't let signals above this level pass the limiter. Default is 1. (range 0.0625..1, default 1, runtime-tunable)
- release: Come back from limiting to attenuation 1.0 in this amount of milliseconds. Default is 50 milliseconds. (range 1..8000, default 50, runtime-tunable)
Constructors
- AlimiterSettings({bool enabled = false, bool asc = false, double asc_level = 0.5, double attack = 5.0, bool latency = false, bool level = true, double level_in = 1.0, double level_out = 1.0, double limit = 1.0, double release = 50.0})
-
Creates an AlimiterSettings with the given parameter values.
const
Properties
- asc → bool
-
enable asc
final
- asc_level → double
-
set asc level
final
- attack → double
-
set attack
final
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- latency → bool
-
compensate delay
final
- level → bool
-
auto level
final
- level_in → double
-
set input level
final
- level_out → double
-
set output level
final
- limit → double
-
set limit
final
- release → double
-
set release
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? enabled, bool? asc, double? asc_level, double? attack, bool? latency, bool? level, double? level_in, double? level_out, double? limit, double? release}) → AlimiterSettings - Returns a copy of this AlimiterSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- asc_levelDefault → const double
- Default value for asc_level.
- asc_levelMax → const double
- Maximum value for asc_level.
- asc_levelMin → const double
- Minimum value for asc_level.
- attackDefault → const double
- Default value for attack.
- attackMax → const double
- Maximum value for attack.
- attackMin → const double
- Minimum value for attack.
- level_inDefault → const double
- Default value for level_in.
- level_inMax → const double
- Maximum value for level_in.
- level_inMin → const double
- Minimum value for level_in.
- level_outDefault → const double
- Default value for level_out.
- level_outMax → const double
- Maximum value for level_out.
- level_outMin → const double
- Minimum value for level_out.
- limitDefault → const double
- Default value for limit.
- limitMax → const double
- Maximum value for limit.
- limitMin → const double
- Minimum value for limit.
- releaseDefault → const double
- Default value for release.
- releaseMax → const double
- Maximum value for release.
- releaseMin → const double
- Minimum value for release.