AphaseshiftSettings class final
Configuration for the aphaseshift audio effect.
Apply phase shift to input audio samples.
The filter accepts the following options:
Parameters:
- level: Set output gain applied to final output. Allowed range is from 0.0 to 1.0. Default value is 1.0. (range 0.0..1.0, default 1, runtime-tunable)
- order: Set filter order used for filtering. Allowed range is from 1 to 16. Default value is 8. (range 1..16, default 8, runtime-tunable)
- shift: Specify phase shift. Allowed range is from -1.0 to 1.0. Default value is 0.0. (range -1.0..1.0, default 0, runtime-tunable)
Constructors
- AphaseshiftSettings({bool enabled = false, double level = 1.0, int order = 8, double shift = 0.0})
-
Creates an AphaseshiftSettings with the given parameter values.
const
Properties
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- level → double
-
set output level
final
- order → int
-
set filter order
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shift → double
-
set phase shift
final
Methods
-
copyWith(
{bool? enabled, double? level, int? order, double? shift}) → AphaseshiftSettings - Returns a copy of this AphaseshiftSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- levelDefault → const double
- Default value for level.
- levelMax → const double
- Maximum value for level.
- levelMin → const double
- Minimum value for level.
- orderDefault → const int
- Default value for order.
- orderMax → const int
- Maximum value for order.
- orderMin → const int
- Minimum value for order.
- shiftDefault → const double
- Default value for shift.
- shiftMax → const double
- Maximum value for shift.
- shiftMin → const double
- Minimum value for shift.