AsetrateSettings class final
Configuration for the asetrate audio effect.
Set the sample rate without altering the PCM data. This will result in a change of speed and pitch.
The filter accepts the following options:
Constructors
- AsetrateSettings({bool enabled = false})
-
Creates an AsetrateSettings with the given parameter values.
const
Properties
Methods
-
copyWith(
{bool? enabled}) → AsetrateSettings - Returns a copy of this AsetrateSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override