BassSettings class final
Configuration for the bass audio effect.
Boost or cut the bass (lower) frequencies of the audio using a two-pole shelving filter with a response similar to that of a standard hi-fi's tone-controls. This is also known as shelving equalisation (EQ).
The filter accepts the following options:
Parameters:
- f: Set the filter's central frequency and so can be used to extend or reduce the frequency range to be boosted or cut. The default value is
100Hz. (range 0..999999, default 100) - frequency: Set the filter's central frequency and so can be used to extend or reduce the frequency range to be boosted or cut. The default value is
100Hz. (range 0..999999, default 100) - g: Give the gain at 0 Hz. Its useful range is about -20 (for a large cut) to +20 (for a large boost). Beware of clipping when using a positive gain. (range -900..900, default 0)
- gain: Give the gain at 0 Hz. Its useful range is about -20 (for a large cut) to +20 (for a large boost). Beware of clipping when using a positive gain. (range -900..900, default 0)
- p: Set number of poles. Default is 2. (range 1..2, default 2)
- poles: Set number of poles. Default is 2. (range 1..2, default 2)
Constructors
Properties
Methods
-
copyWith(
{bool? enabled, double? f, double? frequency, double? g, double? gain, int? p, int? poles}) → BassSettings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override