Format enum
Audio sample format passed to mpv's audio-format property.
Set via Player.setAudioFormat; reset to mpv's auto-pick with Format.auto. The wire-level value mpv expects is exposed via mpvValue. Unknown / empty values map back to auto.
Values
- auto → const Format
-
Let mpv pick the format (mpv's
no/ unset). Default.const Format('no') - u8 → const Format
-
8-bit unsigned integer (interleaved).
const Format('u8') - u8Planar → const Format
-
8-bit unsigned integer (planar).
const Format('u8p') - s16 → const Format
-
16-bit signed integer (interleaved).
const Format('s16') - s16Planar → const Format
-
16-bit signed integer (planar).
const Format('s16p') - s32 → const Format
-
32-bit signed integer (interleaved).
const Format('s32') - s32Planar → const Format
-
32-bit signed integer (planar).
const Format('s32p') - float32 → const Format
-
32-bit float (interleaved).
const Format('float') - float32Planar → const Format
-
32-bit float (planar).
const Format('floatp') - float64 → const Format
-
64-bit float (interleaved).
const Format('double') - float64Planar → const Format
-
64-bit float (planar).
const Format('doublep')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mpvValue → String
-
The wire-level string mpv expects on the
audio-formatproperty.final - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited