MediaSessionCommandSetShuffle class final
The MediaSessionCommand.setShuffle variant — toggle shuffle to the carried shuffle state.
- Inheritance
-
- Object
- MediaSessionCommand
- MediaSessionCommandSetShuffle
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shuffle → bool
-
New shuffle state requested by the OS UI. The package
auto-applies it via Player.setShuffle.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override