Mirror of libmpv's mpv_error return codes (the subset this package uses).
Negative values indicate an error; mpvErrorSuccess (0) means success.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- mpvErrorAoInitFailed → const int
-
Initializing the audio output failed (
MPV_ERROR_AO_INIT_FAILED). - mpvErrorCommand → const int
-
A command failed during execution (
MPV_ERROR_COMMAND). - mpvErrorEventQueueFull → const int
-
The event ringbuffer is full (
MPV_ERROR_EVENT_QUEUE_FULL). - mpvErrorGeneric → const int
-
An unspecified error occurred (
MPV_ERROR_GENERIC). - mpvErrorInvalidParameter → const int
-
A function received an invalid parameter (
MPV_ERROR_INVALID_PARAMETER). - mpvErrorLoadingFailed → const int
-
Loading the requested file/URL failed (
MPV_ERROR_LOADING_FAILED). - mpvErrorNomem → const int
-
Memory allocation failed (
MPV_ERROR_NOMEM). - mpvErrorNothingToPlay → const int
-
There was nothing to play (
MPV_ERROR_NOTHING_TO_PLAY). - mpvErrorNotImplemented → const int
-
The API function is not implemented (
MPV_ERROR_NOT_IMPLEMENTED). - mpvErrorOptionError → const int
-
Setting the option failed (
MPV_ERROR_OPTION_ERROR). - mpvErrorOptionFormat → const int
-
The option value has an unsupported format (
MPV_ERROR_OPTION_FORMAT). - mpvErrorOptionNotFound → const int
-
The named option does not exist (
MPV_ERROR_OPTION_NOT_FOUND). - mpvErrorPropertyError → const int
-
A generic error occurred accessing the property
(
MPV_ERROR_PROPERTY_ERROR). - mpvErrorPropertyFormat → const int
-
The property cannot be used in the requested format
(
MPV_ERROR_PROPERTY_FORMAT). - mpvErrorPropertyNotFound → const int
-
The named property does not exist (
MPV_ERROR_PROPERTY_NOT_FOUND). -
The property exists but is currently unavailable
(
MPV_ERROR_PROPERTY_UNAVAILABLE). - mpvErrorSuccess → const int
-
No error (
MPV_ERROR_SUCCESS). - mpvErrorUninitialized → const int
-
The mpv core was not configured/initialized (
MPV_ERROR_UNINITIALIZED). - mpvErrorUnknownFormat → const int
-
The file format could not be determined (
MPV_ERROR_UNKNOWN_FORMAT). - mpvErrorUnsupported → const int
-
The operation is not supported (
MPV_ERROR_UNSUPPORTED). - mpvErrorVoInitFailed → const int
-
Initializing the video output failed (
MPV_ERROR_VO_INIT_FAILED).