PlayerConfiguration class
Initial configuration for a Player instance.
All fields are immutable and must be set at construction time.
Constructors
- PlayerConfiguration({bool autoPlay = false, double initialVolume = 100.0, String logLevel = 'warn', String? audioClientName})
-
const
Properties
- audioClientName → String?
-
final
- autoPlay → bool
-
If
true, playback starts automatically as soon as a track finishes loading. Default:false.final - hashCode → int
-
The hash code for this object.
no setterinherited
- initialVolume → double
-
Initial volume level (0–100). Default:
100.final - logLevel → String
-
mpv log level forwarded to the
Player.stream.logstream.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited