RubberbandSettings class final
Configuration for the rubberband audio effect.
Apply time-stretching and pitch-shifting with librubberband.
To enable compilation of this filter, you need to configure FFmpeg with
--enable-librubberband.
The filter accepts the following options:
Parameters:
- channels: set channels (range 0..2147483647, default 0)
- detector: set detector (range 0..2147483647, default 0)
- formant: set formant (range 0..2147483647, default 0)
- phase: set phase (range 0..2147483647, default 0)
- pitch: Set pitch scale factor. (range 0.01..100, default 1, runtime-tunable)
- pitchq: set pitch quality (range 0..2147483647, default 0)
- smoothing: set smoothing (range 0..2147483647, default 0)
- tempo: Set tempo scale factor. (range 0.01..100, default 1, runtime-tunable)
- transients: Set transients detector. Possible values are: (range 0..2147483647, default 0)
- window: set window (range 0..2147483647, default 0)
Constructors
- RubberbandSettings({bool enabled = false, RubberbandChannels channels = RubberbandChannels.apart, RubberbandDetector detector = RubberbandDetector.compound, RubberbandFormant formant = RubberbandFormant.shifted, RubberbandPhase phase = RubberbandPhase.laminar, double pitch = 1.0, RubberbandPitch pitchq = RubberbandPitch.quality, RubberbandSmoothing smoothing = RubberbandSmoothing.off, double tempo = 1.0, RubberbandTransients transients = RubberbandTransients.crisp, RubberbandWindow window = RubberbandWindow.standard})
-
Creates an RubberbandSettings with the given parameter values.
const
Properties
- channels → RubberbandChannels
-
set channels
final
- detector → RubberbandDetector
-
set detector
final
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- formant → RubberbandFormant
-
set formant
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- phase → RubberbandPhase
-
set phase
final
- pitch → double
-
set pitch scale factor
final
- pitchq → RubberbandPitch
-
set pitch quality
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smoothing → RubberbandSmoothing
-
set smoothing
final
- tempo → double
-
set tempo scale factor
final
- transients → RubberbandTransients
-
set transients
final
- window → RubberbandWindow
-
set window
final
Methods
-
copyWith(
{bool? enabled, RubberbandChannels? channels, RubberbandDetector? detector, RubberbandFormant? formant, RubberbandPhase? phase, double? pitch, RubberbandPitch? pitchq, RubberbandSmoothing? smoothing, double? tempo, RubberbandTransients? transients, RubberbandWindow? window}) → RubberbandSettings - Returns a copy of this RubberbandSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- pitchDefault → const double
- Default value for pitch.
- pitchMax → const double
- Maximum value for pitch.
- pitchMin → const double
- Minimum value for pitch.
- tempoDefault → const double
- Default value for tempo.
- tempoMax → const double
- Maximum value for tempo.
- tempoMin → const double
- Minimum value for tempo.