StereowidenSettings class final
Configuration for the stereowiden audio effect.
This filter enhance the stereo effect by suppressing signal common to both channels and by delaying the signal of left into right and vice versa, thereby widening the stereo effect.
The filter accepts the following options:
Parameters:
- crossfeed: Cross feed of left into right with inverted phase. This helps in suppressing the mono. If the value is 1 it will cancel all the signal common to both channels. Default is 0.3. (range 0..0.8, default .3, runtime-tunable)
- delay: Time in milliseconds of the delay of left signal into right and vice versa. Default is 20 milliseconds. (range 1..100, default 20)
- drymix: Set level of input signal of original channel. Default is 0.8. (range 0..1.0, default .8, runtime-tunable)
- feedback: Amount of gain in delayed signal into right and vice versa. Gives a delay effect of left signal in right output and vice versa which gives widening effect. Default is 0.3. (range 0..0.9, default .3, runtime-tunable)
Constructors
- StereowidenSettings({bool enabled = false, double crossfeed = .3, double delay = 20.0, double drymix = .8, double feedback = .3})
-
Creates an StereowidenSettings with the given parameter values.
const
Properties
- crossfeed → double
-
set cross feed
final
- delay → double
-
set delay time
final
- drymix → double
-
set dry-mix
final
- enabled → bool
-
Whether this effect is inserted into the audio chain.
final
- feedback → double
-
set feedback gain
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? enabled, double? crossfeed, double? delay, double? drymix, double? feedback}) → StereowidenSettings - Returns a copy of this StereowidenSettings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFilterString(
) → String - Returns the audio chain entry for this effect. Only non-default parameters are emitted.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- crossfeedDefault → const double
- Default value for crossfeed.
- crossfeedMax → const double
- Maximum value for crossfeed.
- crossfeedMin → const double
- Minimum value for crossfeed.
- delayDefault → const double
- Default value for delay.
- delayMax → const double
- Maximum value for delay.
- delayMin → const double
- Minimum value for delay.
- drymixDefault → const double
- Default value for drymix.
- drymixMax → const double
- Maximum value for drymix.
- drymixMin → const double
- Minimum value for drymix.
- feedbackDefault → const double
- Default value for feedback.
- feedbackMax → const double
- Maximum value for feedback.
- feedbackMin → const double
- Minimum value for feedback.